<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'type_birthday' => '祝此人生日快樂',
    'type_phone_call' => '呼叫',
    'type_lunch' => '與此人共進午餐',
    'type_hangout' => '與此人約會',
    'type_email' => '電子郵件',
    'type_birthday_kid' => '祝此人的孩子生日快樂',
];
